@@ -57,7 +57,11 @@ def login(username, password=None):
     if username:
         system_state.username = username
     if not system_state.username:
-        system_state.username = get_default("username", "root")
+        try:
+            system_state.username = get_default("username", "root")
+        except KeyboardInterrupt:
+            print "\n%% Aborted login"
+            sys.exit(1)
     else:
         print "Logging in as %s" % system_state.username
     system_state.cnm_connector = CnmConnector(system_state.cnm_url,
@@ -73,7 +77,8 @@ def login(username, password=None):
             else:
                 system_state.set_auth(USER)
             break
-        except UnexpectedDataException:
+        except UnexpectedDataException, ude:
+            print ude
             user_output(["Bad username or password."], FAIL)
             tries += 1
         except ServerException, sex:
